Documentation
¶
Index ¶
- type EntitlementsManager
- func (m *EntitlementsManager) Add(entitlements ...entitlement.Entitlement) error
- func (m *EntitlementsManager) AddDefault(entName string) error
- func (m *EntitlementsManager) Enforce() error
- func (m *EntitlementsManager) GetProfile() (secprofile.Profile, error)
- func (m *EntitlementsManager) HasEntitlement(ent entitlement.Entitlement) (bool, error)
- func (m *EntitlementsManager) SetProfile(profile secprofile.Profile) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EntitlementsManager ¶
type EntitlementsManager struct {
// contains filtered or unexported fields
}
EntitlementsManager generates enforceable profiles from its entitlements and domains state
func NewEntitlementsManager ¶
func NewEntitlementsManager(profile secprofile.Profile) *EntitlementsManager
NewEntitlementsManager instantiates an EntitlementsManager object with the given profile default
func (*EntitlementsManager) Add ¶
func (m *EntitlementsManager) Add(entitlements ...entitlement.Entitlement) error
Add adds the given entitlements to the current entitlements list, updates the domain name system and enforce the entitlement on the security profile
func (*EntitlementsManager) AddDefault ¶
func (m *EntitlementsManager) AddDefault(entName string) error
AddDefault adds a default entitlement identified by entName which must be a default identifier.
func (*EntitlementsManager) Enforce ¶
func (m *EntitlementsManager) Enforce() error
Enforce applies the constraints on the security profile and updates it to be used for the container
func (*EntitlementsManager) GetProfile ¶
func (m *EntitlementsManager) GetProfile() (secprofile.Profile, error)
GetProfile returns the current state of the security profile
func (*EntitlementsManager) HasEntitlement ¶
func (m *EntitlementsManager) HasEntitlement(ent entitlement.Entitlement) (bool, error)
HasEntitlement returns whether the given entitlement is registered in the current entitlements list
func (*EntitlementsManager) SetProfile ¶
func (m *EntitlementsManager) SetProfile(profile secprofile.Profile) error
SetProfile sets the entitlement manager's security profile