parser

package
v0.0.0-...-80ec3b1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2017 License: Apache-2.0 Imports: 5 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsValidDomainName

func IsValidDomainName(domain string) bool

IsValidDomainName returns whether a given string is a valid domain name

func IsValidDomainNameList

func IsValidDomainNameList(domain []string) bool

IsValidDomainNameList returns whether the list of domain names contains all valid domain names

func IsValidIdentifier

func IsValidIdentifier(identifier string) bool

IsValidIdentifier returns whether the given string is a valid identifier

func ParseIntEntitlement

func ParseIntEntitlement(entitlementFormat string) (domain []string, id string, value int64, err error)

ParseIntEntitlement parses an entitlement with the following format: "domain-name.identifier=int64-value"

func ParseStringEntitlement

func ParseStringEntitlement(entitlementFormat string) (domain []string, id, value string, err error)

ParseStringEntitlement parses an entitlement with the following format: "domain-name.identifier=string-value"

func ParseVoidEntitlement

func ParseVoidEntitlement(entitlementFormat string) (domain []string, id string, err error)

ParseVoidEntitlement parses an entitlement with the following format: "domain-name.identifier"

Types

This section is empty.

Jump to