Documentation
¶
Index ¶
- func IsValidDomainName(domain string) bool
- func IsValidDomainNameList(domain []string) bool
- func IsValidIdentifier(identifier string) bool
- func ParseIntEntitlement(entitlementFormat string) (domain []string, id string, value int64, err error)
- func ParseStringEntitlement(entitlementFormat string) (domain []string, id, value string, err error)
- func ParseVoidEntitlement(entitlementFormat string) (domain []string, id string, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsValidDomainName ¶
IsValidDomainName returns whether a given string is a valid domain name
func IsValidDomainNameList ¶
IsValidDomainNameList returns whether the list of domain names contains all valid domain names
func IsValidIdentifier ¶
IsValidIdentifier returns whether the given string is a valid identifier
func ParseIntEntitlement ¶
func ParseIntEntitlement(entitlementFormat string) (domain []string, id string, value int64, err error)
ParseIntEntitlement parses an entitlement with the following format: "domain-name.identifier=int64-value"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.